@@ -1,12 +1,15 @@
 import unittest
-from collective.geo.contentlocations.tests.base import ContentlocationsTestCase
+from collective.geo.contentlocations.tests import base
+
+
+class TestSetup(base.TestCase):
 
-class TestSetup(ContentlocationsTestCase):
-    
     def test_portal_actions(self):
-        location_action = self.portal.portal_actions.object.get('locations', False)
+        pa = self.portal.portal_actions
+        location_action = pa.object.get('locations',False)
         self.failUnless(location_action)
 
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(TestSetup))
